<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<html>
<head>
    <title style="color: red">小米南京会议纪要</title>
    <link rel="icon" href='https://static.easyicon.net/preview/119/1193422.gif' } sizes="32x32">


</head>
<body bgcolor="rgb(0,0,0)">

<!--{% if message %}-->
<!--<p style="color:red">{{ message }}</p>-->
<!--{% endif %}-->

<div style="text-align: center">

    <p>
        <img src='https://cloud.d.xiaomi.net/react/static/media/LOGO36.d3d970c2.png'/>
    </p>


    <form action="/meeting" method="post">
        <fieldset>
            <legend style="text-align: center">南京会议纪要</legend>

            <p>
                姓名：<input name="name" placeholder="姓名" value="{{ username }}" required>
                <br/>
                <br/>

                项目：<input name="project" placeholder="项目" required>
                <br/>
                <br/>
            </p>

            <p>
                进度：
                <textarea name="progress" rows="5" cols="128" required
                          placeholder="1. ... 换行
2. ..."></textarea>
                <!--两行空格-->
                {% for i in range(2) %} <br/> {% endfor %}

                <button type="submit" style="color: darkblue">
                    Push
                </button>
                <br/>
            <h4 style="color: darkblue">重新提交可覆盖</h4>


            <h4 style="color: whitesmoke">
                <hr/>
                {{dic}}
                <!--                {%if text%}-->
                <!--                {% for i in text.split('\n') %}-->
                <!--                {{i}}<br/>-->
                <!--                {% endfor %}-->
                <!--                {%endif%}-->
            </h4>



            </p>


        </fieldset>
    </form>
</div>
</body>
</html>